import { jsx } from 'react/jsx-runtime';
import { forwardRef, useRef, useState, useEffect, isValidElement, cloneElement } from 'react';
import { T as TextField } from './TextField-Bp1q4hMI-2jGZG2k2.js';
import { u as useMergeRefs } from './floating-ui.react-Domgunz0.js';

const InputMask = forwardRef(
  ({
    children,
    mask,
    defaultMaskCharacter = "_",
    value,
    defaultValue,
    onChange,
    inputProps,
    customMaskHandler
  }, ref) => {
    const lastCursorPos = useRef(0);
    const [internalValue, _setInternalValue] = useState(
      defaultValue || value || ""
    );
    const valueRef = useRef("");
    const controlled = typeof value === "string";
    const setInternalValue = (val) => {
      valueRef.current = applyMask(val);
      _setInternalValue(valueRef.current);
      requestAnimationFrame(() => {
        inputRef.current?.setSelectionRange(
          lastCursorPos.current,
          lastCursorPos.current
        );
      });
    };
    const currentValue = value ?? internalValue;
    const [fixedCharacters, setFixedCharacters] = useState([]);
    const inputRef = useRef(null);
    const passInRef = useMergeRefs([inputRef, ref]);
    useEffect(() => {
      if (defaultValue) {
        setInternalValue(defaultValue);
      } else if (value) {
        setInternalValue(value);
        requestAnimationFrame(() => {
          inputRef.current?.setSelectionRange(
            lastCursorPos.current,
            lastCursorPos.current
          );
        });
      } else {
        setInternalValue("");
      }
    }, [defaultValue, value]);
    useEffect(() => {
      if (value && defaultValue) {
        console.warn(
          "Warning: InputMask contains both 'value' and 'defaultValue' props. Input elements should not switch from uncontrolled to controlled or vice versa. Decide between using a controlled or uncontrolled input element and remove one of these props."
        );
      }
    }, [value, defaultValue]);
    const handleInputChange = (e) => {
      e.preventDefault();
      e.stopPropagation();
      if (controlled) {
        const newVal = applyMask(value);
        if (e.target.value !== newVal) {
          e.target.value = newVal;
          onChange?.({ ...e, target: { ...e.target, value: newVal } });
        }
      }
      if (!controlled && e.target.value !== internalValue) {
        e.target.value = internalValue;
      }
      onChange?.({ ...e, target: { ...e.target, value: internalValue } });
    };
    const applyMask = (value2) => {
      let maskedValue = "";
      for (let i = 0; i < mask.length; i++) {
        const maskChar = mask[i];
        const inputChar = value2[i];
        if (isAcceptableChar(inputChar, maskChar)) {
          maskedValue += inputChar;
        } else if (["9", "a", "*"].includes(maskChar)) {
          maskedValue += defaultMaskCharacter;
        } else {
          maskedValue += maskChar;
        }
      }
      return maskedValue;
    };
    useEffect(() => {
      const fixed = [];
      const maskChars = ["a", "9", "*"];
      mask.split("").forEach((char) => {
        if (!maskChars.includes(char) && !fixed.includes(char)) {
          fixed.push(char);
        }
      });
      setFixedCharacters(fixed);
    }, [mask]);
    useEffect(() => {
      if (inputRef.current && inputRef.current.value !== currentValue) {
        inputRef.current.value = currentValue;
      }
    }, [inputRef]);
    const getCursorPos = (currentIndex, nextIndex, lastKey) => {
      if (currentIndex === void 0 || nextIndex === void 0) {
        const cursorPosition = internalValue.indexOf(defaultMaskCharacter);
        if (cursorPosition > -1) {
          lastCursorPos.current = cursorPosition;
          !controlled && requestAnimationFrame(() => {
            inputRef.current?.setSelectionRange(
              cursorPosition,
              cursorPosition
            );
          });
          return;
        } else {
          lastCursorPos.current = internalValue.length;
          !controlled && requestAnimationFrame(() => {
            inputRef.current?.setSelectionRange(
              internalValue.length,
              internalValue.length
            );
            lastCursorPos.current = internalValue.length;
          });
          return;
        }
      }
      if (controlled) {
        requestAnimationFrame(() => {
          inputRef.current?.setSelectionRange(currentIndex, currentIndex);
        });
      }
      if (lastKey === "Backspace") {
        for (let i = nextIndex; i >= 1; i--) {
          if (
            // Skip any position that is fixed.
            !fixedCharacters.includes(mask[i - 1]) && internalValue[i - 1] !== defaultMaskCharacter
          ) {
            !controlled && requestAnimationFrame(() => {
              inputRef.current?.setSelectionRange(i, i);
            });
            lastCursorPos.current = i;
            return;
          }
        }
        requestAnimationFrame(() => {
          inputRef.current?.setSelectionRange(0, 0);
        });
        lastCursorPos.current = 0;
        return;
      }
      for (let i = nextIndex; i < mask.length; i++) {
        if (!fixedCharacters.includes(mask[i])) {
          !controlled && requestAnimationFrame(() => {
            inputRef.current?.setSelectionRange(i, i);
          });
          lastCursorPos.current = i;
          return;
        }
      }
      lastCursorPos.current = internalValue.length;
      return;
    };
    const onInputClick = (e) => {
      e.preventDefault();
      e.stopPropagation();
      inputProps?.onClick?.(e);
    };
    const onInputBlur = (e) => {
      e.preventDefault();
      e.stopPropagation();
      inputProps?.onBlur?.(e);
    };
    const onInputFocus = (e) => {
      e.preventDefault();
      e.stopPropagation();
      getCursorPos();
      requestAnimationFrame(() => {
        inputRef.current?.setSelectionRange(
          lastCursorPos.current,
          lastCursorPos.current
        );
      });
      inputProps?.onFocus?.(e);
    };
    const isAcceptableChar = (char, maskChar) => {
      if (maskChar === "9") {
        return /\d/.test(char);
      }
      if (maskChar === "a") {
        return /[a-zA-Z]/.test(char);
      }
      if (maskChar === "*") {
        return /[a-zA-Z0-9]/.test(char);
      }
      return false;
    };
    const applyCustomMaskHandler = (key) => {
      if (!customMaskHandler?.length) return false;
      for (const item of customMaskHandler) {
        const { matchPattern, startPosition, endPosition } = item.match;
        if (typeof inputRef.current?.selectionStart === "number" && endPosition !== inputRef.current?.selectionStart + 1)
          continue;
        const substring = valueRef.current.substring(startPosition, endPosition - 1) + key;
        if (matchPattern.test(substring)) {
          const { applyPattern, caretOffset } = item.apply;
          const newValue = substring.replace(matchPattern, applyPattern);
          setInternalValue(
            valueRef.current.substring(0, startPosition) + newValue + valueRef.current.substring(endPosition)
          );
          lastCursorPos.current += caretOffset;
          if (!controlled) {
            requestAnimationFrame(() => {
              inputRef.current?.setSelectionRange(
                lastCursorPos.current,
                lastCursorPos.current
              );
            });
          }
          return true;
        }
      }
      return false;
    };
    const handleKeyDown = (e) => {
      let indexStart = inputRef.current?.selectionStart || 0;
      let indexEnd = inputRef.current?.selectionEnd || 0;
      if ((e.ctrlKey || e.metaKey) && e.key.toLowerCase() === "v") {
        inputProps?.onKeyDown?.(e);
        return;
      }
      if (e.key === "Backspace") {
        if (indexStart === indexEnd) {
          setInternalValue(
            valueRef.current.substring(0, indexStart - 1) + " " + valueRef.current.substring(indexEnd)
          );
          getCursorPos(indexStart, indexStart - 1, e.key);
        } else {
          setInternalValue(
            valueRef.current.substring(0, indexStart) + " ".repeat(indexEnd - indexStart) + valueRef.current.substring(indexEnd)
          );
          getCursorPos(indexStart, indexStart + 1, e.key);
        }
      } else if (e.key === "Delete") {
        if (indexStart === indexEnd) {
          setInternalValue(
            valueRef.current.substring(0, indexStart) + " " + valueRef.current.substring(indexEnd + 1)
          );
          getCursorPos(indexStart, indexEnd, e.key);
        } else {
          setInternalValue(
            valueRef.current.substring(0, indexStart) + " ".repeat(indexEnd - indexStart) + valueRef.current.substring(indexEnd)
          );
          getCursorPos(indexStart, indexEnd, e.key);
        }
      } else if (e.key.length === 1) {
        const isApplied = applyCustomMaskHandler(e.key);
        if (isApplied) {
          inputProps?.onKeyDown?.(e);
          return;
        }
        if (indexStart === mask.length && lastCursorPos.current !== mask.length) {
          indexStart = lastCursorPos.current;
          indexEnd = lastCursorPos.current;
        }
        if (!isAcceptableChar(e.key, mask[indexStart]) && ["9", "a", "*"].includes(mask[indexStart])) {
          requestAnimationFrame(() => {
            inputRef.current?.setSelectionRange(indexStart, indexStart);
            lastCursorPos.current = indexStart;
          });
          return;
        }
        if (indexStart === indexEnd) {
          setInternalValue(
            valueRef.current.substring(0, indexStart) + e.key + valueRef.current.substring(indexEnd + 1)
          );
          getCursorPos(indexStart, indexStart + 1, e.key);
        } else {
          setInternalValue(
            valueRef.current.substring(0, indexStart) + e.key + " ".repeat(indexEnd - indexStart - 1) + valueRef.current.substring(indexEnd)
          );
          getCursorPos(indexStart, indexStart + 1, e.key);
        }
      }
      inputProps?.onKeyDown?.(e);
    };
    const handlePaste = (e) => {
      const indexStart = inputRef.current?.selectionStart || 0;
      const indexEnd = inputRef.current?.selectionEnd || 0;
      const pastedValue = e.clipboardData.getData("text");
      if (indexStart === indexEnd || indexEnd - indexStart <= pastedValue.length) {
        setInternalValue(
          valueRef.current.substring(0, indexStart) + pastedValue + valueRef.current.substring(indexStart + pastedValue.length)
        );
        getCursorPos(indexStart + pastedValue.length);
        return;
      }
      setInternalValue(
        valueRef.current.substring(0, indexStart) + pastedValue + " ".repeat(indexEnd - indexStart - pastedValue.length) + valueRef.current.substring(indexEnd)
      );
      getCursorPos(indexEnd);
    };
    const mergedInputProps = {
      ...inputProps,
      ...children && isValidElement(children) ? children.props : {},
      value: applyMask(currentValue),
      onChange: handleInputChange,
      onPaste: handlePaste,
      onClick: onInputClick,
      onBlur: onInputBlur,
      onFocus: onInputFocus,
      onKeyDown: handleKeyDown,
      ref: passInRef
    };
    return children && isValidElement(children) && children.type === "input" ? cloneElement(children, {
      ...mergedInputProps
    }) : /* @__PURE__ */ jsx(TextField, { ...mergedInputProps });
  }
);
InputMask.displayName = "InputMask";

export { InputMask as I };
//# sourceMappingURL=InputMask-DfpkWGmY-D8QEut94.js.map
